.. _recipe_asr.infraredpolarizability:

asr.infraredpolarizability
==========================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.infraredpolarizability`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.infraredpolarizability.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.infraredpolarizability

or as a python module

.. code-block:: console

   $ python -m asr.infraredpolarizability

Detailed description
--------------------
Infrared polarizability.

Steps
-----


asr.infraredpolarizability
^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.infraredpolarizability.main
   